summaryrefslogtreecommitdiffstats
path: root/kdeui/klanguagebutton.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kdeui/klanguagebutton.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/klanguagebutton.h')
-rw-r--r--kdeui/klanguagebutton.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdeui/klanguagebutton.h b/kdeui/klanguagebutton.h
index 0736b50c7..c167930db 100644
--- a/kdeui/klanguagebutton.h
+++ b/kdeui/klanguagebutton.h
@@ -144,9 +144,9 @@ public:
*/
TQString current() const;
/**
* Returns TRUE if the combobox tqcontains id.
*/
- bool tqcontains( const TQString & id ) const;
+ bool contains( const TQString & id ) const;
/**
* Sets id as current item.
*/
@@ -144,9 +144,9 @@ public:
TQString current() const;
/**
- * Returns TRUE if the combobox tqcontains id.
+ * Returns TRUE if the combobox contains id.
*/